import os
import cv2

# Define the source and target directories
source_dir = 'data/train/'
target_dir = 'data/train_flipped/'

# Define the folder to skip
skip_folder = 'not_important'

# Create the target directory if it doesn't exist
if not os.path.exists(target_dir):
    os.makedirs(target_dir)

# Iterate through each folder in the source directory
for letter_folder in os.listdir(source_dir):
    # Skip the folder if it is the skip_folder
    if letter_folder == skip_folder:
        continue
    
    source_folder_path = os.path.join(source_dir, letter_folder)
    target_folder_path = os.path.join(target_dir, letter_folder)
    
    # Create the corresponding folder in the target directory
    if not os.path.exists(target_folder_path):
        os.makedirs(target_folder_path)
    
    # Iterate through each image in the letter folder
    for image_file in os.listdir(source_folder_path):
        source_image_path = os.path.join(source_folder_path, image_file)
        target_image_path = os.path.join(target_folder_path, image_file)
        
        # Read the image
        image = cv2.imread(source_image_path)
        
        # Check if the image was loaded correctly
        if image is None:
            print(f"Warning: Could not read image {source_image_path}")
            continue
        
        # Flip the image horizontally
        flipped_image = cv2.flip(image, 1)
        
        # Save the flipped image to the target directory
        cv2.imwrite(target_image_path, flipped_image)

print("Flipped images created successfully, excluding the 'not_important' folder.")
